summary refs log tree commit diff stats
diff options
context:
space:
mode:
authorAndinus <andinus@nand.sh>2020-04-15 19:20:22 +0530
committerAndinus <andinus@nand.sh>2020-04-15 19:20:22 +0530
commit6e5a88bc7749b3fe4d9419b95a2ba2b596e3f837 (patch)
tree3cbea158f28ad56729dd88705bc6a4b94083f7b9
parentf479b82ff8aa13b953590a13d31de93de8e53ec2 (diff)
downloadlynx-6e5a88bc7749b3fe4d9419b95a2ba2b596e3f837.tar.gz
Rename func UnveilPath to Unveil
UnveilPath is confusing, it's kept only for backwards compatibility &
users should use Unveil & UnveilStrict instead of UnveilPath &
UnveilPathStrict.
-rw-r--r--README.org52
-rw-r--r--unveil.go (renamed from path.go)19
-rw-r--r--unveil_other.go (renamed from path_other.go)0
3 files changed, 41 insertions, 30 deletions
diff --git a/README.org b/README.org
index 4cfe1f4..b21bc00 100644
--- a/README.org
+++ b/README.org
@@ -13,6 +13,32 @@ currently only /OpenBSD/ is supported.
 | GitHub (Mirror) | [[https://github.com/andinus/lynx][Lynx - GitHub]]  |
 
 * Examples
+** Unveil / UnveilStrict
+Unveil takes a path, permission & unveils it, it will return an error if unveil
+fails at any step. "no such file or directory" error is ignored, if you want to
+get that error too then use UnveilStrict.
+
+#+BEGIN_SRC go
+package main
+
+import "tildegit.org/andinus/lynx"
+
+func main() {
+	path := "/dev/null"
+	flags := "rw"
+
+	err = lynx.Unveil(path, flags)
+	if err != nil {
+		log.Fatal(err)
+	}
+
+	// This will return an error if the path doesn't exist.
+	err = lynx.UnveilStrict(path, flags)
+	if err != nil {
+		log.Fatal(err)
+	}
+}
+#+END_SRC
 ** UnveilCommands
 UnveilCommands takes a slice of commands & unveils them one by one, it will
 return an error if unveil fails at any step. "no such file or directory" error
@@ -64,32 +90,6 @@ func main() {
 	}
 }
 #+END_SRC
-** UnveilPath / UnveilPathStrict
-UnveilPath takes a path, permission & unveils it, it will return an error if
-unveil fails at any step. "no such file or directory" error is ignored, if you
-want to get that error too then use UnveilPathStrict.
-
-#+BEGIN_SRC go
-package main
-
-import "tildegit.org/andinus/lynx"
-
-func main() {
-	path := "/dev/null"
-	flags := "rw"
-
-	err = lynx.UnveilPath(path, flags)
-	if err != nil {
-		log.Fatal(err)
-	}
-
-	// This will return an error if the path doesn't exist.
-	err = lynx.UnveilPathStrict(path, flags)
-	if err != nil {
-		log.Fatal(err)
-	}
-}
-#+END_SRC
 ** UnveilBlock
 UnveilBlock is just a wrapper around unix.UnveilBlock, it does nothing extra.
 You should use unix.UnveilBlock.
diff --git a/path_other.go b/unveil_other.go
index a0273c9..a0273c9 100644
--- a/path_other.go
+++ b/unveil_other.go
diff --git a/path.go b/unveil.go
index a04c723..3069ec6 100644
--- a/path.go
+++ b/unveil.go
@@ -4,10 +4,10 @@ package lynx
 
 import "golang.org/x/sys/unix"
 
-// UnveilPath takes a path, permission & unveils it, returning an
+// Unveil takes a path, permission & unveils it, returning an
 // error if unveil fails. "no such file or directory" error is
 // ignored.
-func UnveilPath(path string, flags string) (err error) {
+func Unveil(path string, flags string) (err error) {
 	err = unix.Unveil(path, flags)
 
 	// "no such file or directory" error is ignored.
@@ -22,7 +22,18 @@ func UnveilPath(path string, flags string) (err error) {
 	return nil
 }
 
-// UnveilPathStrict is just a wrapper around unix.Unveil.
-func UnveilPathStrict(path string, flags string) error {
+// UnveilPath is kept for backwards compatibility, use Unveil instead.
+func UnveilPath(path string, flags string) (err error) {
+	return Unveil(path, flags)
+}
+
+// UnveilStrict is just a wrapper around unix.Unveil.
+func UnveilStrict(path string, flags string) error {
 	return unix.Unveil(path, flags)
 }
+
+// UnveilPathStrict is kept for backwards compatibility, use
+// UnveilStrict instead.
+func UnveilPathStrict(path string, flags string) error {
+	return UnveilStrict(path, flags)
+}